fcm_config library

Classes

ActiveNotification
Details of an active notification.
AndroidBitmap<T>
Represents a bitmap on Android.
AndroidFlutterLocalNotificationsPlugin
Android implementation of the local notifications plugin.
AndroidInitializationSettings
Plugin initialization settings for Android.
AndroidNotification
Android specific properties of a RemoteNotification.
AndroidNotificationAction
Mirrors the Action class in AndroidX.
AndroidNotificationActionInput
Mirrors the RemoteInput functionality available in NotificationCompat.
AndroidNotificationChannel
Settings for Android notification channels.
AndroidNotificationChannelGroup
A group of related Android notification channels.
AndroidNotificationDetails
Contains notification details specific to Android.
AndroidNotificationSound
Represents an Android notification sound.
AppleNotification
Apple specific properties of a RemoteNotification.
AppleNotificationSound
Represents the sound property for AppleNotification
AssetsLinuxIcon
Represents an icon from the Flutter Assets directory. Currently the assets directory is data/flutter_assets which is located on the path relative to the executable file.
AssetsLinuxSound
Represents a sound from the Flutter Assets directory.
BigPictureStyleInformation
Used to pass the content for an Android notification displayed using the big picture style.
BigTextStyleInformation
Used to pass the content for an Android notification displayed using the big text style.
BitmapFilePathAndroidIcon
Represents a file path to a bitmap that should be used for as an icon on Android.
ByteArrayAndroidBitmap
Represents a base64 encoded AndroidBitmap.
ByteArrayAndroidIcon
Represents a bitmap asset belonging to the Flutter application that should be used for as an icon on Android.
ByteDataLinuxIcon
Represents an icon from a raw image data bytes, see LinuxRawIconData.
ContentUriAndroidIcon
Represents a content URI that should be used for as an icon on Android.
DarwinInitializationSettings
Plugin initialization settings for Darwin-based operating systems such as iOS and macOS
DarwinNotificationAction
Describes the notification action itself.
DarwinNotificationAttachment
Represents an attachment for a notification on Darwin-based operation systems such as iOS and macOS
DarwinNotificationAttachmentThumbnailClippingRect
Represents the clipping rectangle used for the thumbnail image.
DarwinNotificationCategory
Corresponds to the UNNotificationCategory type which is used to configure notification categories and accompanying options.
DarwinNotificationDetails
Configures notification details specific to Darwin-based operation systems such as iOS and macOS
DefaultStyleInformation
The default Android notification style.
DrawableResourceAndroidBitmap
Represents a drawable resource belonging to the Android application that should be used as a bitmap on Android.
DrawableResourceAndroidIcon
Represents a drawable resource belonging to the Android application that should be used as an icon on Android.
FCMConfig
FCMNotificationClickListener
This widget can listen to notification tap instead of mixin
FCMNotificationListener
This mixin can listen to incoming notification instead of mixin
FilePathAndroidBitmap
Represents a file path that should be used for a bitmap on Android.
FilePathLinuxIcon
Represents an icon located at the path in the file system. It сan be either an absolute UNIX path or a file:// URI scheme, for example:
FirebaseMessaging
The FirebaseMessaging entry point.
FlutterBitmapAssetAndroidIcon
Represents a bitmap asset belonging to the Flutter application that should be used for as an icon on Android.
FlutterLocalNotificationsPlatform
The interface that all implementations of flutter_local_notifications must implement.
FlutterLocalNotificationsPlugin
Provides cross-platform functionality for displaying local notifications.
FlutterLocalNotificationsWindows
The Windows implementation of package:flutter_local_notifications.
InboxStyleInformation
Used to pass the content for an Android notification displayed using the inbox style.
InitializationSettings
Settings for initializing the plugin for each platform.
IOSFlutterLocalNotificationsPlugin
iOS implementation of the local notifications plugin.
LinuxFlutterLocalNotificationsPlugin
A stub implementation to satisfy compilation of multi-platform packages that depend on flutter_local_notifications_linux. This should never actually be created.
LinuxInitializationSettings
Plugin initialization settings for Linux.
LinuxNotificationAction
Represents an action, that send a request message back to the notification client when invoked. This functionality may not be implemented by the notification server, conforming clients should check if it's available using LinuxServerCapabilities. For more information, please see Desktop Notifications Specification https://specifications.freedesktop.org/notification-spec/latest/ar01s02.html
LinuxNotificationDetails
Configures notification details specific to Linux. The system may not support all features.
LinuxNotificationIcon
Represents Linux notification icon.
LinuxNotificationLocation
Represents the location on the screen that the notification should point to.
LinuxNotificationSound
Represents Linux notification sound.
LinuxNotificationTimeout
The timeout of the Linux notification.
LinuxRawIconData
Represents an icon in the raw image data.
LinuxServerCapabilities
Represents capabilities, implemented by the Linux notification server.
MacOSFlutterLocalNotificationsPlugin
macOS implementation of the local notifications plugin.
MediaStyleInformation
Used to pass the content for an Android notification displayed using the media style.
Message
Represents a message used in Android messaging style notifications.
MessagingStyleInformation
Used to pass the content for an Android notification displayed using the messaging style.
MsixUtils
Helpful methods to support MSIX and package identity.
NotificationAppLaunchDetails
Contains details on the notification that launched the application.
NotificationDetails
Contains notification details specific to each platform.
NotificationResponse
Details of a Notification Action that was triggered.
NotificationsEnabledOptions
Data class that represent current state of notification options.
NotificationSettings
Represents the devices notification settings.
PendingNotificationRequest
Details of a pending notification that has not been delivered.
Person
Details of a person e.g. someone who sent a message.
RawResourceAndroidNotificationSound
Represents a raw resource belonging to the Android application that should be used for the notification sound.
RemoteMessage
A class representing a message sent from Firebase Cloud Messaging.
RemoteNotification
A class representing a notification which has been constructed and sent to the device via FCM.
StyleInformation
Abstract class for defining an Android notification style
ThemeLinuxIcon
Represents a system theme icon. See https://www.freedesktop.org/wiki/Specifications/icon-naming-spec/ for more help.
ThemeLinuxSound
Represents a system theme sound. See https://www.freedesktop.org/wiki/Specifications/sound-theme-spec/ for more help.
UriAndroidNotificationSound
Represents a URI on the Android device that should be used for the notification sound.
WebNotification
Web specific properties of a RemoteNotification.
WebNotificationDetails
WindowsAction
A button in a Windows notification.
WindowsColumn
A vertical column of text and images in a Windows notification.
WindowsHeader
A header that groups multiple Windows notifications.
WindowsImage
An image in a Windows notification.
WindowsInitializationSettings
Plugin initialization settings for Windows.
WindowsInput
A text or multiple choice input element in a Windows notification.
WindowsNotificationAudio
Specifies custom audio to play during a notification.
WindowsNotificationDetails
Contains notification details specific to Windows.
WindowsNotificationPart
A text or image element in a Windows notification.
WindowsNotificationText
Text in a Windows notification.
WindowsProgressBar
A progress bar in a Windows notification.
WindowsRow
A group of notification content that must be displayed as a whole row.
WindowsSelection
An option that can be selected by a WindowsSelectionInput.
WindowsSelectionInput
A multiple choice input.
WindowsTextInput
A text input.

Enums

AndroidNotificationCategory
The available categories for Android notifications.
AndroidNotificationChannelAction
The available actions for managing notification channels.
AndroidNotificationPriority
An enum representing a notification priority on Android.
AndroidNotificationStyle
The available notification styles on Android.
AndroidNotificationVisibility
An enum representing the visibility level of a notification on Android.
AndroidScheduleMode
Used to specify how notifications should be scheduled on Android.
AndroidServiceForegroundType
The available foreground types for an Android service.
AndroidServiceStartType
The available start types for an Android service.
AppleNotificationSetting
An enum representing a notification setting for this app on the device.
AppleShowPreviewSetting
An enum representing the show previews notification setting for this app on the device.
AudioAttributesUsage
The available audio attributes usages for an Android service.
AuthorizationStatus
Represents the current status of the platforms notification permissions.
DarwinNotificationActionOption
Describes when & how the notification action is displayed.
DarwinNotificationCategoryOption
Desribes the options of each notification category.
DateTimeComponents
The components of a date and time representations.
Day
The days of the week.
GroupAlertBehavior
The available alert behaviours for grouped notifications.
Importance
The available importance levels for Android notifications.
InterruptionLevel
Type used to indicate the importance and delivery timing of a notification.
LinuxHintValueType
Represents the notification hint value type.
LinuxIconType
Specifies the Linux notification icon type.
LinuxNotificationCategory
Categories of notifications.
LinuxNotificationUrgency
The urgency level of the Linux notification.
LinuxSoundType
Specifies the Linux notification sound type.
NotificationResponseType
The possible notification response types
NotificationUpdateResult
The result of updating a notification.
NotificationVisibility
Defines the notification visibility on the lockscreen.
Priority
Priority for notifications on Android 7.1 and lower.
RepeatInterval
The available intervals for periodically showing notifications.
SemanticAction
The available meanings that can be associated with a notification action.
WindowsActionPlacement
Decides how a WindowsAction is placed on a notification.
WindowsActivationType
Decides how the WindowsAction will launch the app.
WindowsButtonStyle
Decides how a WindowsAction will be styled.
WindowsHeaderActivation
Decides how the application will open when the header is pressed.
WindowsImageCrop
How a Windows notification image can be cropped.
WindowsImagePlacement
Where a Windows notification image can be placed.
WindowsInputType
The type of a WindowsInput.
WindowsNotificationBehavior
Decides how a WindowsAction will react to being pressed.
WindowsNotificationDuration
The duration for a Windows notification.
WindowsNotificationScenario
The scenario a notification is being used for.
WindowsNotificationSound
A preset sound for a Windows notification.
WindowsTextPlacement
Where text can be placed in a Windows notification.

Mixins

FCMNotificationClickMixin<T extends StatefulWidget>
This mixin can listen to notification tap
FCMNotificationMixin<T extends StatefulWidget>
This mixin can listen to incoming notification

Extensions

MapExt on RemoteMessage

Typedefs

BackgroundMessageHandler = Future<void> Function(RemoteMessage message)
Defines a handler for incoming remote message payloads.
DidReceiveBackgroundNotificationResponseCallback = void Function(NotificationResponse details)
Signature of callback triggered on background isolate when a user taps on a notification or a notification action.
DidReceiveLocalNotificationCallback = void Function(int id, String? title, String? body, String? payload)
Signature of the callback that is triggered when a notification is shown whilst the app is in the foreground.
DidReceiveNotificationResponseCallback = void Function(NotificationResponse details)
Signature of callback triggered on main isolate when a user taps on a notification or a notification action.